from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class NestedField(_message.Message):
    __slots__ = ("fieldName", "seriesId", "intValue", "stringValue", "doubleValue", "field", "longValue", "isList")
    FIELDNAME_FIELD_NUMBER: _ClassVar[int]
    SERIESID_FIELD_NUMBER: _ClassVar[int]
    INTVALUE_FIELD_NUMBER: _ClassVar[int]
    STRINGVALUE_FIELD_NUMBER: _ClassVar[int]
    DOUBLEVALUE_FIELD_NUMBER: _ClassVar[int]
    FIELD_FIELD_NUMBER: _ClassVar[int]
    LONGVALUE_FIELD_NUMBER: _ClassVar[int]
    ISLIST_FIELD_NUMBER: _ClassVar[int]
    fieldName: str
    seriesId: int
    intValue: _containers.RepeatedScalarFieldContainer[int]
    stringValue: _containers.RepeatedScalarFieldContainer[str]
    doubleValue: _containers.RepeatedScalarFieldContainer[float]
    field: _containers.RepeatedCompositeFieldContainer[NestedField]
    longValue: _containers.RepeatedScalarFieldContainer[int]
    isList: bool
    def __init__(self, fieldName: _Optional[str] = ..., seriesId: _Optional[int] = ..., intValue: _Optional[_Iterable[int]] = ..., stringValue: _Optional[_Iterable[str]] = ..., doubleValue: _Optional[_Iterable[float]] = ..., field: _Optional[_Iterable[_Union[NestedField, _Mapping]]] = ..., longValue: _Optional[_Iterable[int]] = ..., isList: bool = ...) -> None: ...



from fameprotobuf import Field_pb2 as _Field_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ProtoContract(_message.Message):
    __slots__ = ("senderId", "receiverId", "productName", "firstDeliveryTime", "deliveryIntervalInSteps", "expirationTime", "field", "metadata")
    SENDERID_FIELD_NUMBER: _ClassVar[int]
    RECEIVERID_FIELD_NUMBER: _ClassVar[int]
    PRODUCTNAME_FIELD_NUMBER: _ClassVar[int]
    FIRSTDELIVERYTIME_FIELD_NUMBER: _ClassVar[int]
    DELIVERYINTERVALINSTEPS_FIELD_NUMBER: _ClassVar[int]
    EXPIRATIONTIME_FIELD_NUMBER: _ClassVar[int]
    FIELD_FIELD_NUMBER: _ClassVar[int]
    METADATA_FIELD_NUMBER: _ClassVar[int]
    senderId: int
    receiverId: int
    productName: str
    firstDeliveryTime: int
    deliveryIntervalInSteps: int
    expirationTime: int
    field: _containers.RepeatedCompositeFieldContainer[_Field_pb2.NestedField]
    metadata: str
    def __init__(self, senderId: _Optional[int] = ..., receiverId: _Optional[int] = ..., productName: _Optional[str] = ..., firstDeliveryTime: _Optional[int] = ..., deliveryIntervalInSteps: _Optional[int] = ..., expirationTime: _Optional[int] = ..., field: _Optional[_Iterable[_Union[_Field_pb2.NestedField, _Mapping]]] = ..., metadata: _Optional[str] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ExecutionData.proto
# Protobuf Python Version: 4.25.4
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x13\x45xecutionData.proto\x12\x08iobinary\"\xbb\x03\n\rExecutionData\x12\x32\n\x08versions\x18\x01 \x01(\x0b\x32 .iobinary.ExecutionData.Versions\x12\x36\n\nsimulation\x18\x02 \x01(\x0b\x32\".iobinary.ExecutionData.Simulation\x12<\n\rconfiguration\x18\x03 \x01(\x0b\x32%.iobinary.ExecutionData.Configuration\x1ak\n\x08Versions\x12\x14\n\x0c\x66\x61meProtobuf\x18\x01 \x01(\t\x12\x0e\n\x06\x66\x61meIo\x18\x02 \x01(\t\x12\x10\n\x08\x66\x61meCore\x18\x03 \x01(\t\x12\x0e\n\x06python\x18\x04 \x01(\t\x12\x0b\n\x03jvm\x18\x05 \x01(\t\x12\n\n\x02os\x18\x06 \x01(\t\x1a@\n\nSimulation\x12\r\n\x05start\x18\x01 \x01(\t\x12\x14\n\x0c\x64urationInMS\x18\x02 \x01(\x03\x12\r\n\x05ticks\x18\x03 \x01(\x03\x1aQ\n\rConfiguration\x12\x11\n\tcoreCount\x18\x01 \x01(\x05\x12\x15\n\routputProcess\x18\x02 \x01(\x05\x12\x16\n\x0eoutputInterval\x18\x03 \x01(\x05\x42(\n\x1b\x64\x65.dlr.gitlab.fame.protobufB\tExecution')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ExecutionData_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\033de.dlr.gitlab.fame.protobufB\tExecution'
  _globals['_EXECUTIONDATA']._serialized_start=34
  _globals['_EXECUTIONDATA']._serialized_end=477
  _globals['_EXECUTIONDATA_VERSIONS']._serialized_start=221
  _globals['_EXECUTIONDATA_VERSIONS']._serialized_end=328
  _globals['_EXECUTIONDATA_SIMULATION']._serialized_start=330
  _globals['_EXECUTIONDATA_SIMULATION']._serialized_end=394
  _globals['_EXECUTIONDATA_CONFIGURATION']._serialized_start=396
  _globals['_EXECUTIONDATA_CONFIGURATION']._serialized_end=477
# @@protoc_insertion_point(module_scope)



from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ModelData(_message.Message):
    __slots__ = ("name", "version", "packages")
    class JavaPackages(_message.Message):
        __slots__ = ("agent", "dataItem", "portable")
        AGENT_FIELD_NUMBER: _ClassVar[int]
        DATAITEM_FIELD_NUMBER: _ClassVar[int]
        PORTABLE_FIELD_NUMBER: _ClassVar[int]
        agent: _containers.RepeatedScalarFieldContainer[str]
        dataItem: _containers.RepeatedScalarFieldContainer[str]
        portable: _containers.RepeatedScalarFieldContainer[str]
        def __init__(self, agent: _Optional[_Iterable[str]] = ..., dataItem: _Optional[_Iterable[str]] = ..., portable: _Optional[_Iterable[str]] = ...) -> None: ...
    NAME_FIELD_NUMBER: _ClassVar[int]
    VERSION_FIELD_NUMBER: _ClassVar[int]
    PACKAGES_FIELD_NUMBER: _ClassVar[int]
    name: str
    version: str
    packages: ModelData.JavaPackages
    def __init__(self, name: _Optional[str] = ..., version: _Optional[str] = ..., packages: _Optional[_Union[ModelData.JavaPackages, _Mapping]] = ...) -> None: ...



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ExecutionData(_message.Message):
    __slots__ = ("versions", "simulation", "configuration")
    class Versions(_message.Message):
        __slots__ = ("fameProtobuf", "fameIo", "fameCore", "python", "jvm", "os")
        FAMEPROTOBUF_FIELD_NUMBER: _ClassVar[int]
        FAMEIO_FIELD_NUMBER: _ClassVar[int]
        FAMECORE_FIELD_NUMBER: _ClassVar[int]
        PYTHON_FIELD_NUMBER: _ClassVar[int]
        JVM_FIELD_NUMBER: _ClassVar[int]
        OS_FIELD_NUMBER: _ClassVar[int]
        fameProtobuf: str
        fameIo: str
        fameCore: str
        python: str
        jvm: str
        os: str
        def __init__(self, fameProtobuf: _Optional[str] = ..., fameIo: _Optional[str] = ..., fameCore: _Optional[str] = ..., python: _Optional[str] = ..., jvm: _Optional[str] = ..., os: _Optional[str] = ...) -> None: ...
    class Simulation(_message.Message):
        __slots__ = ("start", "durationInMS", "ticks")
        START_FIELD_NUMBER: _ClassVar[int]
        DURATIONINMS_FIELD_NUMBER: _ClassVar[int]
        TICKS_FIELD_NUMBER: _ClassVar[int]
        start: str
        durationInMS: int
        ticks: int
        def __init__(self, start: _Optional[str] = ..., durationInMS: _Optional[int] = ..., ticks: _Optional[int] = ...) -> None: ...
    class Configuration(_message.Message):
        __slots__ = ("coreCount", "outputProcess", "outputInterval")
        CORECOUNT_FIELD_NUMBER: _ClassVar[int]
        OUTPUTPROCESS_FIELD_NUMBER: _ClassVar[int]
        OUTPUTINTERVAL_FIELD_NUMBER: _ClassVar[int]
        coreCount: int
        outputProcess: int
        outputInterval: int
        def __init__(self, coreCount: _Optional[int] = ..., outputProcess: _Optional[int] = ..., outputInterval: _Optional[int] = ...) -> None: ...
    VERSIONS_FIELD_NUMBER: _ClassVar[int]
    SIMULATION_FIELD_NUMBER: _ClassVar[int]
    CONFIGURATION_FIELD_NUMBER: _ClassVar[int]
    versions: ExecutionData.Versions
    simulation: ExecutionData.Simulation
    configuration: ExecutionData.Configuration
    def __init__(self, versions: _Optional[_Union[ExecutionData.Versions, _Mapping]] = ..., simulation: _Optional[_Union[ExecutionData.Simulation, _Mapping]] = ..., configuration: _Optional[_Union[ExecutionData.Configuration, _Mapping]] = ...) -> None: ...



from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ScheduledTime(_message.Message):
    __slots__ = ("timeStep",)
    TIMESTEP_FIELD_NUMBER: _ClassVar[int]
    timeStep: int
    def __init__(self, timeStep: _Optional[int] = ...) -> None: ...

class ProtoSetup(_message.Message):
    __slots__ = ("outputInterval", "outputActiveClassNames", "outputComplexDisabled")
    OUTPUTINTERVAL_FIELD_NUMBER: _ClassVar[int]
    OUTPUTACTIVECLASSNAMES_FIELD_NUMBER: _ClassVar[int]
    OUTPUTCOMPLEXDISABLED_FIELD_NUMBER: _ClassVar[int]
    outputInterval: int
    outputActiveClassNames: _containers.RepeatedScalarFieldContainer[str]
    outputComplexDisabled: bool
    def __init__(self, outputInterval: _Optional[int] = ..., outputActiveClassNames: _Optional[_Iterable[str]] = ..., outputComplexDisabled: bool = ...) -> None: ...

class WarmUpMessage(_message.Message):
    __slots__ = ("needed",)
    NEEDED_FIELD_NUMBER: _ClassVar[int]
    needed: bool
    def __init__(self, needed: bool = ...) -> None: ...

class Output(_message.Message):
    __slots__ = ("agentType", "series")
    class AgentType(_message.Message):
        __slots__ = ("className", "field")
        class Field(_message.Message):
            __slots__ = ("fieldId", "fieldName", "indexName")
            FIELDID_FIELD_NUMBER: _ClassVar[int]
            FIELDNAME_FIELD_NUMBER: _ClassVar[int]
            INDEXNAME_FIELD_NUMBER: _ClassVar[int]
            fieldId: int
            fieldName: str
            indexName: _containers.RepeatedScalarFieldContainer[str]
            def __init__(self, fieldId: _Optional[int] = ..., fieldName: _Optional[str] = ..., indexName: _Optional[_Iterable[str]] = ...) -> None: ...
        CLASSNAME_FIELD_NUMBER: _ClassVar[int]
        FIELD_FIELD_NUMBER: _ClassVar[int]
        className: str
        field: _containers.RepeatedCompositeFieldContainer[Output.AgentType.Field]
        def __init__(self, className: _Optional[str] = ..., field: _Optional[_Iterable[_Union[Output.AgentType.Field, _Mapping]]] = ...) -> None: ...
    class Series(_message.Message):
        __slots__ = ("className", "agentId", "line")
        class Line(_message.Message):
            __slots__ = ("timeStep", "column")
            class Column(_message.Message):
                __slots__ = ("fieldId", "value", "entry")
                class Map(_message.Message):
                    __slots__ = ("indexValue", "value")
                    INDEXVALUE_FIELD_NUMBER: _ClassVar[int]
                    VALUE_FIELD_NUMBER: _ClassVar[int]
                    indexValue: _containers.RepeatedScalarFieldContainer[str]
                    value: str
                    def __init__(self, indexValue: _Optional[_Iterable[str]] = ..., value: _Optional[str] = ...) -> None: ...
                FIELDID_FIELD_NUMBER: _ClassVar[int]
                VALUE_FIELD_NUMBER: _ClassVar[int]
                ENTRY_FIELD_NUMBER: _ClassVar[int]
                fieldId: int
                value: float
                entry: _containers.RepeatedCompositeFieldContainer[Output.Series.Line.Column.Map]
                def __init__(self, fieldId: _Optional[int] = ..., value: _Optional[float] = ..., entry: _Optional[_Iterable[_Union[Output.Series.Line.Column.Map, _Mapping]]] = ...) -> None: ...
            TIMESTEP_FIELD_NUMBER: _ClassVar[int]
            COLUMN_FIELD_NUMBER: _ClassVar[int]
            timeStep: int
            column: _containers.RepeatedCompositeFieldContainer[Output.Series.Line.Column]
            def __init__(self, timeStep: _Optional[int] = ..., column: _Optional[_Iterable[_Union[Output.Series.Line.Column, _Mapping]]] = ...) -> None: ...
        CLASSNAME_FIELD_NUMBER: _ClassVar[int]
        AGENTID_FIELD_NUMBER: _ClassVar[int]
        LINE_FIELD_NUMBER: _ClassVar[int]
        className: str
        agentId: int
        line: _containers.RepeatedCompositeFieldContainer[Output.Series.Line]
        def __init__(self, className: _Optional[str] = ..., agentId: _Optional[int] = ..., line: _Optional[_Iterable[_Union[Output.Series.Line, _Mapping]]] = ...) -> None: ...
    AGENTTYPE_FIELD_NUMBER: _ClassVar[int]
    SERIES_FIELD_NUMBER: _ClassVar[int]
    agentType: _containers.RepeatedCompositeFieldContainer[Output.AgentType]
    series: _containers.RepeatedCompositeFieldContainer[Output.Series]
    def __init__(self, agentType: _Optional[_Iterable[_Union[Output.AgentType, _Mapping]]] = ..., series: _Optional[_Iterable[_Union[Output.Series, _Mapping]]] = ...) -> None: ...

class AddressBook(_message.Message):
    __slots__ = ("processId", "agentId")
    PROCESSID_FIELD_NUMBER: _ClassVar[int]
    AGENTID_FIELD_NUMBER: _ClassVar[int]
    processId: int
    agentId: _containers.RepeatedScalarFieldContainer[int]
    def __init__(self, processId: _Optional[int] = ..., agentId: _Optional[_Iterable[int]] = ...) -> None: ...



from fameprotobuf import AgentMessage_pb2 as _AgentMessage_pb2
from fameprotobuf import Services_pb2 as _Services_pb2
from fameprotobuf import InputFile_pb2 as _InputFile_pb2
from fameprotobuf import Model_pb2 as _Model_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class MpiMessage(_message.Message):
    __slots__ = ("scheduledTime", "warmUp", "addressBook", "input", "output", "message", "setup", "model")
    SCHEDULEDTIME_FIELD_NUMBER: _ClassVar[int]
    WARMUP_FIELD_NUMBER: _ClassVar[int]
    ADDRESSBOOK_FIELD_NUMBER: _ClassVar[int]
    INPUT_FIELD_NUMBER: _ClassVar[int]
    OUTPUT_FIELD_NUMBER: _ClassVar[int]
    MESSAGE_FIELD_NUMBER: _ClassVar[int]
    SETUP_FIELD_NUMBER: _ClassVar[int]
    MODEL_FIELD_NUMBER: _ClassVar[int]
    scheduledTime: _Services_pb2.ScheduledTime
    warmUp: _Services_pb2.WarmUpMessage
    addressBook: _Services_pb2.AddressBook
    input: _InputFile_pb2.InputData
    output: _Services_pb2.Output
    message: _AgentMessage_pb2.ProtoMessage
    setup: _Services_pb2.ProtoSetup
    model: _Model_pb2.ModelData
    def __init__(self, scheduledTime: _Optional[_Union[_Services_pb2.ScheduledTime, _Mapping]] = ..., warmUp: _Optional[_Union[_Services_pb2.WarmUpMessage, _Mapping]] = ..., addressBook: _Optional[_Union[_Services_pb2.AddressBook, _Mapping]] = ..., input: _Optional[_Union[_InputFile_pb2.InputData, _Mapping]] = ..., output: _Optional[_Union[_Services_pb2.Output, _Mapping]] = ..., message: _Optional[_Union[_AgentMessage_pb2.ProtoMessage, _Mapping]] = ..., setup: _Optional[_Union[_Services_pb2.ProtoSetup, _Mapping]] = ..., model: _Optional[_Union[_Model_pb2.ModelData, _Mapping]] = ...) -> None: ...

class Bundle(_message.Message):
    __slots__ = ("message",)
    MESSAGE_FIELD_NUMBER: _ClassVar[int]
    message: _containers.RepeatedCompositeFieldContainer[MpiMessage]
    def __init__(self, message: _Optional[_Iterable[_Union[MpiMessage, _Mapping]]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: Services.proto
# Protobuf Python Version: 4.25.4
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0eServices.proto\x12\rcommunication\"!\n\rScheduledTime\x12\x10\n\x08timeStep\x18\x01 \x02(\x03\"c\n\nProtoSetup\x12\x16\n\x0eoutputInterval\x18\x01 \x02(\x05\x12\x1e\n\x16outputActiveClassNames\x18\x02 \x03(\t\x12\x1d\n\x15outputComplexDisabled\x18\x03 \x02(\x08\"\x1f\n\rWarmUpMessage\x12\x0e\n\x06needed\x18\x01 \x02(\x08\"\xc8\x04\n\x06Output\x12\x32\n\tagentType\x18\x01 \x03(\x0b\x32\x1f.communication.Output.AgentType\x12,\n\x06series\x18\x02 \x03(\x0b\x32\x1c.communication.Output.Series\x1a\x94\x01\n\tAgentType\x12\x11\n\tclassName\x18\x01 \x02(\t\x12\x34\n\x05\x66ield\x18\x02 \x03(\x0b\x32%.communication.Output.AgentType.Field\x1a>\n\x05\x46ield\x12\x0f\n\x07\x66ieldId\x18\x01 \x02(\x05\x12\x11\n\tfieldName\x18\x02 \x02(\t\x12\x11\n\tindexName\x18\x03 \x03(\t\x1a\xc4\x02\n\x06Series\x12\x11\n\tclassName\x18\x01 \x02(\t\x12\x0f\n\x07\x61gentId\x18\x02 \x02(\x03\x12/\n\x04line\x18\x03 \x03(\x0b\x32!.communication.Output.Series.Line\x1a\xe4\x01\n\x04Line\x12\x10\n\x08timeStep\x18\x01 \x02(\x03\x12\x38\n\x06\x63olumn\x18\x02 \x03(\x0b\x32(.communication.Output.Series.Line.Column\x1a\x8f\x01\n\x06\x43olumn\x12\x0f\n\x07\x66ieldId\x18\x01 \x02(\x05\x12\r\n\x05value\x18\x02 \x01(\x01\x12;\n\x05\x65ntry\x18\x03 \x03(\x0b\x32,.communication.Output.Series.Line.Column.Map\x1a(\n\x03Map\x12\x12\n\nindexValue\x18\x01 \x03(\t\x12\r\n\x05value\x18\x02 \x02(\t\"5\n\x0b\x41\x64\x64ressBook\x12\x11\n\tprocessId\x18\x01 \x02(\x05\x12\x13\n\x07\x61gentId\x18\x02 \x03(\x03\x42\x02\x10\x01\x42\'\n\x1b\x64\x65.dlr.gitlab.fame.protobufB\x08Services')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'Services_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\033de.dlr.gitlab.fame.protobufB\010Services'
  _globals['_ADDRESSBOOK'].fields_by_name['agentId']._options = None
  _globals['_ADDRESSBOOK'].fields_by_name['agentId']._serialized_options = b'\020\001'
  _globals['_SCHEDULEDTIME']._serialized_start=33
  _globals['_SCHEDULEDTIME']._serialized_end=66
  _globals['_PROTOSETUP']._serialized_start=68
  _globals['_PROTOSETUP']._serialized_end=167
  _globals['_WARMUPMESSAGE']._serialized_start=169
  _globals['_WARMUPMESSAGE']._serialized_end=200
  _globals['_OUTPUT']._serialized_start=203
  _globals['_OUTPUT']._serialized_end=787
  _globals['_OUTPUT_AGENTTYPE']._serialized_start=312
  _globals['_OUTPUT_AGENTTYPE']._serialized_end=460
  _globals['_OUTPUT_AGENTTYPE_FIELD']._serialized_start=398
  _globals['_OUTPUT_AGENTTYPE_FIELD']._serialized_end=460
  _globals['_OUTPUT_SERIES']._serialized_start=463
  _globals['_OUTPUT_SERIES']._serialized_end=787
  _globals['_OUTPUT_SERIES_LINE']._serialized_start=559
  _globals['_OUTPUT_SERIES_LINE']._serialized_end=787
  _globals['_OUTPUT_SERIES_LINE_COLUMN']._serialized_start=644
  _globals['_OUTPUT_SERIES_LINE_COLUMN']._serialized_end=787
  _globals['_OUTPUT_SERIES_LINE_COLUMN_MAP']._serialized_start=747
  _globals['_OUTPUT_SERIES_LINE_COLUMN_MAP']._serialized_end=787
  _globals['_ADDRESSBOOK']._serialized_start=789
  _globals['_ADDRESSBOOK']._serialized_end=842
# @@protoc_insertion_point(module_scope)



from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ProtoDataItem(_message.Message):
    __slots__ = ("dataTypeId", "boolValue", "intValue", "longValue", "floatValue", "doubleValue", "stringValue")
    DATATYPEID_FIELD_NUMBER: _ClassVar[int]
    BOOLVALUE_FIELD_NUMBER: _ClassVar[int]
    INTVALUE_FIELD_NUMBER: _ClassVar[int]
    LONGVALUE_FIELD_NUMBER: _ClassVar[int]
    FLOATVALUE_FIELD_NUMBER: _ClassVar[int]
    DOUBLEVALUE_FIELD_NUMBER: _ClassVar[int]
    STRINGVALUE_FIELD_NUMBER: _ClassVar[int]
    dataTypeId: int
    boolValue: _containers.RepeatedScalarFieldContainer[bool]
    intValue: _containers.RepeatedScalarFieldContainer[int]
    longValue: _containers.RepeatedScalarFieldContainer[int]
    floatValue: _containers.RepeatedScalarFieldContainer[float]
    doubleValue: _containers.RepeatedScalarFieldContainer[float]
    stringValue: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, dataTypeId: _Optional[int] = ..., boolValue: _Optional[_Iterable[bool]] = ..., intValue: _Optional[_Iterable[int]] = ..., longValue: _Optional[_Iterable[int]] = ..., floatValue: _Optional[_Iterable[float]] = ..., doubleValue: _Optional[_Iterable[float]] = ..., stringValue: _Optional[_Iterable[str]] = ...) -> None: ...

class NestedItem(_message.Message):
    __slots__ = ("dataTypeId", "boolValue", "intValue", "longValue", "floatValue", "doubleValue", "stringValue", "timeSeriesId", "component")
    DATATYPEID_FIELD_NUMBER: _ClassVar[int]
    BOOLVALUE_FIELD_NUMBER: _ClassVar[int]
    INTVALUE_FIELD_NUMBER: _ClassVar[int]
    LONGVALUE_FIELD_NUMBER: _ClassVar[int]
    FLOATVALUE_FIELD_NUMBER: _ClassVar[int]
    DOUBLEVALUE_FIELD_NUMBER: _ClassVar[int]
    STRINGVALUE_FIELD_NUMBER: _ClassVar[int]
    TIMESERIESID_FIELD_NUMBER: _ClassVar[int]
    COMPONENT_FIELD_NUMBER: _ClassVar[int]
    dataTypeId: int
    boolValue: _containers.RepeatedScalarFieldContainer[bool]
    intValue: _containers.RepeatedScalarFieldContainer[int]
    longValue: _containers.RepeatedScalarFieldContainer[int]
    floatValue: _containers.RepeatedScalarFieldContainer[float]
    doubleValue: _containers.RepeatedScalarFieldContainer[float]
    stringValue: _containers.RepeatedScalarFieldContainer[str]
    timeSeriesId: _containers.RepeatedScalarFieldContainer[int]
    component: _containers.RepeatedCompositeFieldContainer[NestedItem]
    def __init__(self, dataTypeId: _Optional[int] = ..., boolValue: _Optional[_Iterable[bool]] = ..., intValue: _Optional[_Iterable[int]] = ..., longValue: _Optional[_Iterable[int]] = ..., floatValue: _Optional[_Iterable[float]] = ..., doubleValue: _Optional[_Iterable[float]] = ..., stringValue: _Optional[_Iterable[str]] = ..., timeSeriesId: _Optional[_Iterable[int]] = ..., component: _Optional[_Iterable[_Union[NestedItem, _Mapping]]] = ...) -> None: ...

class ProtoMessage(_message.Message):
    __slots__ = ("senderId", "receiverId", "dataItem", "nestedItem")
    SENDERID_FIELD_NUMBER: _ClassVar[int]
    RECEIVERID_FIELD_NUMBER: _ClassVar[int]
    DATAITEM_FIELD_NUMBER: _ClassVar[int]
    NESTEDITEM_FIELD_NUMBER: _ClassVar[int]
    senderId: int
    receiverId: int
    dataItem: _containers.RepeatedCompositeFieldContainer[ProtoDataItem]
    nestedItem: _containers.RepeatedCompositeFieldContainer[NestedItem]
    def __init__(self, senderId: _Optional[int] = ..., receiverId: _Optional[int] = ..., dataItem: _Optional[_Iterable[_Union[ProtoDataItem, _Mapping]]] = ..., nestedItem: _Optional[_Iterable[_Union[NestedItem, _Mapping]]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: Bundle.proto
# Protobuf Python Version: 4.25.4
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from fameprotobuf import AgentMessage_pb2 as AgentMessage__pb2
from fameprotobuf import Services_pb2 as Services__pb2
from fameprotobuf import InputFile_pb2 as InputFile__pb2
from fameprotobuf import Model_pb2 as Model__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0c\x42undle.proto\x12\x03mpi\x1a\x12\x41gentMessage.proto\x1a\x0eServices.proto\x1a\x0fInputFile.proto\x1a\x0bModel.proto\"\xe4\x02\n\nMpiMessage\x12\x33\n\rscheduledTime\x18\x01 \x01(\x0b\x32\x1c.communication.ScheduledTime\x12,\n\x06warmUp\x18\x02 \x01(\x0b\x32\x1c.communication.WarmUpMessage\x12/\n\x0b\x61\x64\x64ressBook\x18\x03 \x01(\x0b\x32\x1a.communication.AddressBook\x12\"\n\x05input\x18\x04 \x01(\x0b\x32\x13.iobinary.InputData\x12%\n\x06output\x18\x05 \x01(\x0b\x32\x15.communication.Output\x12,\n\x07message\x18\x06 \x01(\x0b\x32\x1b.communication.ProtoMessage\x12(\n\x05setup\x18\x07 \x01(\x0b\x32\x19.communication.ProtoSetup\x12\x1f\n\x05model\x18\x08 \x01(\x0b\x32\x10.model.ModelData\"*\n\x06\x42undle\x12 \n\x07message\x18\x01 \x03(\x0b\x32\x0f.mpi.MpiMessageB\"\n\x1b\x64\x65.dlr.gitlab.fame.protobufB\x03Mpi')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'Bundle_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\033de.dlr.gitlab.fame.protobufB\003Mpi'
  _globals['_MPIMESSAGE']._serialized_start=88
  _globals['_MPIMESSAGE']._serialized_end=444
  _globals['_BUNDLE']._serialized_start=446
  _globals['_BUNDLE']._serialized_end=488
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: InputFile.proto
# Protobuf Python Version: 4.25.4
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from fameprotobuf import Contract_pb2 as Contract__pb2
from fameprotobuf import Field_pb2 as Field__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0fInputFile.proto\x12\x08iobinary\x1a\x0e\x43ontract.proto\x1a\x0b\x46ield.proto\"\xf3\x05\n\tInputData\x12\r\n\x05runId\x18\x01 \x02(\x03\x12\x37\n\nsimulation\x18\x02 \x02(\x0b\x32#.iobinary.InputData.SimulationParam\x12\x35\n\ntimeSeries\x18\x04 \x03(\x0b\x32!.iobinary.InputData.TimeSeriesDao\x12+\n\x05\x61gent\x18\x05 \x03(\x0b\x32\x1c.iobinary.InputData.AgentDao\x12.\n\x08\x63ontract\x18\x06 \x03(\x0b\x32\x1c.communication.ProtoContract\x12\x0e\n\x06schema\x18\x08 \x01(\t\x12\x34\n\nstringSets\x18\t \x03(\x0b\x32 .iobinary.InputData.StringSetDao\x1aJ\n\x0fSimulationParam\x12\x11\n\tstartTime\x18\x01 \x02(\x03\x12\x10\n\x08stopTime\x18\x02 \x02(\x03\x12\x12\n\nrandomSeed\x18\x03 \x02(\x03\x1a\x66\n\rTimeSeriesDao\x12\x10\n\x08seriesId\x18\x01 \x02(\x05\x12\x12\n\nseriesName\x18\x02 \x01(\t\x12\x15\n\ttimeSteps\x18\x04 \x03(\x03\x42\x02\x10\x01\x12\x12\n\x06values\x18\x05 \x03(\x01\x42\x02\x10\x01J\x04\x08\x03\x10\x04\x1a\x61\n\x08\x41gentDao\x12\n\n\x02id\x18\x01 \x02(\x03\x12\x11\n\tclassName\x18\x02 \x02(\t\x12$\n\x05\x66ield\x18\x03 \x03(\x0b\x32\x15.iobinary.NestedField\x12\x10\n\x08metadata\x18\x04 \x01(\t\x1a\xa0\x01\n\x0cStringSetDao\x12\x0c\n\x04name\x18\x01 \x02(\t\x12>\n\x05value\x18\x02 \x03(\x0b\x32/.iobinary.InputData.StringSetDao.StringSetEntry\x12\x10\n\x08metadata\x18\x03 \x01(\t\x1a\x30\n\x0eStringSetEntry\x12\x0c\n\x04name\x18\x01 \x02(\t\x12\x10\n\x08metadata\x18\x02 \x01(\tJ\x04\x08\x03\x10\x04J\x04\x08\x07\x10\x08\x42$\n\x1b\x64\x65.dlr.gitlab.fame.protobufB\x05Input')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'InputFile_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\033de.dlr.gitlab.fame.protobufB\005Input'
  _globals['_INPUTDATA_TIMESERIESDAO'].fields_by_name['timeSteps']._options = None
  _globals['_INPUTDATA_TIMESERIESDAO'].fields_by_name['timeSteps']._serialized_options = b'\020\001'
  _globals['_INPUTDATA_TIMESERIESDAO'].fields_by_name['values']._options = None
  _globals['_INPUTDATA_TIMESERIESDAO'].fields_by_name['values']._serialized_options = b'\020\001'
  _globals['_INPUTDATA']._serialized_start=59
  _globals['_INPUTDATA']._serialized_end=814
  _globals['_INPUTDATA_SIMULATIONPARAM']._serialized_start=362
  _globals['_INPUTDATA_SIMULATIONPARAM']._serialized_end=436
  _globals['_INPUTDATA_TIMESERIESDAO']._serialized_start=438
  _globals['_INPUTDATA_TIMESERIESDAO']._serialized_end=540
  _globals['_INPUTDATA_AGENTDAO']._serialized_start=542
  _globals['_INPUTDATA_AGENTDAO']._serialized_end=639
  _globals['_INPUTDATA_STRINGSETDAO']._serialized_start=642
  _globals['_INPUTDATA_STRINGSETDAO']._serialized_end=802
  _globals['_INPUTDATA_STRINGSETDAO_STRINGSETENTRY']._serialized_start=754
  _globals['_INPUTDATA_STRINGSETDAO_STRINGSETENTRY']._serialized_end=802
# @@protoc_insertion_point(module_scope)



from fameprotobuf import Contract_pb2 as _Contract_pb2
from fameprotobuf import Field_pb2 as _Field_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class InputData(_message.Message):
    __slots__ = ("runId", "simulation", "timeSeries", "agent", "contract", "schema", "stringSets")
    class SimulationParam(_message.Message):
        __slots__ = ("startTime", "stopTime", "randomSeed")
        STARTTIME_FIELD_NUMBER: _ClassVar[int]
        STOPTIME_FIELD_NUMBER: _ClassVar[int]
        RANDOMSEED_FIELD_NUMBER: _ClassVar[int]
        startTime: int
        stopTime: int
        randomSeed: int
        def __init__(self, startTime: _Optional[int] = ..., stopTime: _Optional[int] = ..., randomSeed: _Optional[int] = ...) -> None: ...
    class TimeSeriesDao(_message.Message):
        __slots__ = ("seriesId", "seriesName", "timeSteps", "values")
        SERIESID_FIELD_NUMBER: _ClassVar[int]
        SERIESNAME_FIELD_NUMBER: _ClassVar[int]
        TIMESTEPS_FIELD_NUMBER: _ClassVar[int]
        VALUES_FIELD_NUMBER: _ClassVar[int]
        seriesId: int
        seriesName: str
        timeSteps: _containers.RepeatedScalarFieldContainer[int]
        values: _containers.RepeatedScalarFieldContainer[float]
        def __init__(self, seriesId: _Optional[int] = ..., seriesName: _Optional[str] = ..., timeSteps: _Optional[_Iterable[int]] = ..., values: _Optional[_Iterable[float]] = ...) -> None: ...
    class AgentDao(_message.Message):
        __slots__ = ("id", "className", "field", "metadata")
        ID_FIELD_NUMBER: _ClassVar[int]
        CLASSNAME_FIELD_NUMBER: _ClassVar[int]
        FIELD_FIELD_NUMBER: _ClassVar[int]
        METADATA_FIELD_NUMBER: _ClassVar[int]
        id: int
        className: str
        field: _containers.RepeatedCompositeFieldContainer[_Field_pb2.NestedField]
        metadata: str
        def __init__(self, id: _Optional[int] = ..., className: _Optional[str] = ..., field: _Optional[_Iterable[_Union[_Field_pb2.NestedField, _Mapping]]] = ..., metadata: _Optional[str] = ...) -> None: ...
    class StringSetDao(_message.Message):
        __slots__ = ("name", "value", "metadata")
        class StringSetEntry(_message.Message):
            __slots__ = ("name", "metadata")
            NAME_FIELD_NUMBER: _ClassVar[int]
            METADATA_FIELD_NUMBER: _ClassVar[int]
            name: str
            metadata: str
            def __init__(self, name: _Optional[str] = ..., metadata: _Optional[str] = ...) -> None: ...
        NAME_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        METADATA_FIELD_NUMBER: _ClassVar[int]
        name: str
        value: _containers.RepeatedCompositeFieldContainer[InputData.StringSetDao.StringSetEntry]
        metadata: str
        def __init__(self, name: _Optional[str] = ..., value: _Optional[_Iterable[_Union[InputData.StringSetDao.StringSetEntry, _Mapping]]] = ..., metadata: _Optional[str] = ...) -> None: ...
    RUNID_FIELD_NUMBER: _ClassVar[int]
    SIMULATION_FIELD_NUMBER: _ClassVar[int]
    TIMESERIES_FIELD_NUMBER: _ClassVar[int]
    AGENT_FIELD_NUMBER: _ClassVar[int]
    CONTRACT_FIELD_NUMBER: _ClassVar[int]
    SCHEMA_FIELD_NUMBER: _ClassVar[int]
    STRINGSETS_FIELD_NUMBER: _ClassVar[int]
    runId: int
    simulation: InputData.SimulationParam
    timeSeries: _containers.RepeatedCompositeFieldContainer[InputData.TimeSeriesDao]
    agent: _containers.RepeatedCompositeFieldContainer[InputData.AgentDao]
    contract: _containers.RepeatedCompositeFieldContainer[_Contract_pb2.ProtoContract]
    schema: str
    stringSets: _containers.RepeatedCompositeFieldContainer[InputData.StringSetDao]
    def __init__(self, runId: _Optional[int] = ..., simulation: _Optional[_Union[InputData.SimulationParam, _Mapping]] = ..., timeSeries: _Optional[_Iterable[_Union[InputData.TimeSeriesDao, _Mapping]]] = ..., agent: _Optional[_Iterable[_Union[InputData.AgentDao, _Mapping]]] = ..., contract: _Optional[_Iterable[_Union[_Contract_pb2.ProtoContract, _Mapping]]] = ..., schema: _Optional[str] = ..., stringSets: _Optional[_Iterable[_Union[InputData.StringSetDao, _Mapping]]] = ...) -> None: ...
